from setuptools import setup, find_packages

setup(
    name='rzt',
    version='0.0.1',
    author='Razorthink',
    author_email='sandeep.kumar@razorthink.com',
    description='Razor SDK for Razorthink AI',
    url='https://razorthink.com',
    packages=find_packages(),
    python_requires='>=3.7'
)
